# fcecodec Copyright (C) 2021-2024 Benjamin Futasz <https://github.com/bfut>
#
# You may not redistribute this program without its source code.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""
  test_scripts.py - testing scripts in ./scripts
"""
import os
import pathlib
import subprocess
import sys

# import pytest

# Look for local build, if not installed
try:
    import fcecodec as fc
except ModuleNotFoundError:
    import sys
    PATH = pathlib.Path(pathlib.Path(__file__).parent / "../python/build")
    print(PATH)
    for x in PATH.glob("**"):
        sys.path.append(str(x.resolve()))
    del PATH

    import fcecodec as fc

script_path = pathlib.Path(__file__).parent
filepath_fce_input = script_path / "fce/Snowman_car.fce"
filepath_fce3_output = script_path / ".out/test_scripts3.fce"
filepath_fce4_output = script_path / ".out/test_scripts4.fce"
filepath_fce4m_output = script_path / ".out/test_scripts4m.fce"

filepath_obj_output = script_path / ".out/test_scripts.obj"
filepath_mtl_output = script_path / ".out/test_scripts.mtl"
objtexname = "car00_Snowman.png"

#
if (script_path / ".out").exists() and not (script_path / ".out").is_dir():
    os.remove(script_path / ".out")
    os.mkdir(script_path / ".out")
elif not (script_path / ".out").exists():
    os.mkdir(script_path / ".out")

#
sys.path.append(str((pathlib.Path(__file__).parent / "../python/").resolve()))
from bfut_mywrappers import *


# Generate src->X and src->X->Y
def generate_data(version1, version2, filepath_fce_output):
    outpath = str(filepath_fce_output) + f"diff{version1}{version2}"
    mesh = fc.Mesh()

    mesh = LoadFce(mesh, filepath_fce_input)
    WriteFce(version1, mesh, filepath_fce_output, center_parts=0)

    mesh = LoadFce(mesh, filepath_fce_output)
    WriteFce(version2, mesh, outpath, center_parts=0)
    return outpath


def test_Fce2Obj():
    # The following OBJ string is:
    # Copyright (C) 2001-2022 Benjamin Futasz <https://github.com/bfut>
    # License: CC BY-NC-SA 4.0
    #     <https://creativecommons.org/licenses/by-nc-sa/4.0/legalcode>
    fcecodec_Fce2Obj_src = \
"""# fcecodec OBJ File: 'Snowman_car.obj'
# github.com/bfut/fcecodec
mtllib Snowman_car.mtl

o :HLRW
#part position -0.001832 -0.579950 -1.036170

#4 verts
v -0.001069 -0.411364 0.800680
v -0.002594 -0.411364 1.271659
v -0.001069 -0.748537 0.800680
v -0.002594 -0.748537 1.271659

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -1.001825 -0.579950 1.033379
vn -1.001825 -0.579950 1.033379
vn -1.001825 -0.579950 1.033379
vn -1.001825 -0.579950 1.033379

#2 faces (verts: 1..4)
usemtl 0x000
s 1
f 1/1/1 3/2/3 2/3/2
usemtl 0x000
s 1
f 3/4/3 4/5/4 2/6/2


o DAMAGE_:HLRW
#part position -0.001832 -0.579950 -1.036170

#4 verts
v 0.004825 -0.411364 -1.022349
v 0.003304 -0.411364 -0.551370
v 0.004825 -0.748537 -1.022349
v 0.003304 -0.748537 -0.551370

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -1.001825 -0.579950 1.033385
vn -1.001825 -0.579950 1.033384
vn -1.001825 -0.579950 1.033385
vn -1.001825 -0.579950 1.033384

#2 faces (verts: 5..8)
usemtl 0x000
s 1
f 5/7/5 7/8/7 6/9/6
usemtl 0x000
s 1
f 7/10/7 8/11/8 6/12/6


o :HRRW
#part position -0.001832 -0.579950 -1.036170

#4 verts
v -0.001069 -0.411364 0.800680
v -0.002594 -0.411364 1.271659
v -0.001069 -0.748537 0.800680
v -0.002594 -0.748537 1.271659

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -1.001825 -0.579950 1.033379
vn -1.001825 -0.579950 1.033379
vn -1.001825 -0.579950 1.033379
vn -1.001825 -0.579950 1.033379

#2 faces (verts: 9..12)
usemtl 0x000
s 1
f 9/13/9 11/14/11 10/15/10
usemtl 0x000
s 1
f 11/16/11 12/17/12 10/18/10


o DAMAGE_:HRRW
#part position -0.001832 -0.579950 -1.036170

#4 verts
v 0.004825 -0.411364 -1.022349
v 0.003304 -0.411364 -0.551370
v 0.004825 -0.748537 -1.022349
v 0.003304 -0.748537 -0.551370

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -1.001825 -0.579950 1.033385
vn -1.001825 -0.579950 1.033384
vn -1.001825 -0.579950 1.033385
vn -1.001825 -0.579950 1.033384

#2 faces (verts: 13..16)
usemtl 0x000
s 1
f 13/19/13 15/20/15 14/21/14
usemtl 0x000
s 1
f 15/22/15 16/23/16 14/24/14


o :HLFW
#part position 0.004065 -0.579950 0.786859

#4 verts
v 0.004825 -0.411364 -1.022349
v 0.003304 -0.411364 -0.551370
v 0.004825 -0.748537 -1.022349
v 0.003304 -0.748537 -0.551370

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645

#2 faces (verts: 17..20)
usemtl 0x000
s 1
f 17/25/17 19/26/19 18/27/18
usemtl 0x000
s 1
f 19/28/19 20/29/20 18/30/18


o DAMAGE_:HLFW
#part position 0.004065 -0.579950 0.786859

#4 verts
v 0.004825 -0.411364 -1.022349
v 0.003304 -0.411364 -0.551370
v 0.004825 -0.748537 -1.022349
v 0.003304 -0.748537 -0.551370

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645

#2 faces (verts: 21..24)
usemtl 0x000
s 1
f 21/31/21 23/32/23 22/33/22
usemtl 0x000
s 1
f 23/34/23 24/35/24 22/36/22


o :HB
#part position 0.000000 0.000000 -0.000000

#143 verts
v 0.015465 0.741107 0.059659
v -0.008335 0.748319 -0.019506
v 0.074838 0.750324 -0.008219
v 0.109403 0.751403 0.030385
v 0.113263 0.751403 0.118447
v 0.073610 0.750324 0.168350
v 0.014029 0.748319 0.178678
v -0.073548 0.746314 0.167690
v -0.112178 0.745237 0.118123
v -0.111564 0.745237 0.039454
v -0.072413 0.746314 -0.009051
v -0.011870 0.573638 -0.050829
v 0.084814 0.575917 -0.037025
v 0.130749 0.577163 0.020229
v 0.130834 0.577163 0.108571
v 0.084156 0.575917 0.166384
v 0.002247 0.573638 0.180336
v -0.085535 0.571362 0.165976
v -0.131146 0.570114 0.109539
v -0.131556 0.570114 0.020380
v -0.084878 0.571362 -0.037433
v 0.003023 0.566945 -0.164266
v 0.165135 0.570568 -0.130010
v 0.258395 0.572346 -0.018642
v 0.259203 0.572346 0.145119
v 0.163876 0.570568 0.259096
v -0.000378 0.566945 0.292566
v -0.166602 0.563324 0.258301
v -0.257967 0.561244 0.151271
v -0.260628 0.561244 -0.016666
v -0.166330 0.563324 -0.130181
v 0.003023 0.554590 -0.164280
v 0.170818 0.558285 -0.129997
v 0.263285 0.560410 -0.020252
v 0.264775 0.560410 0.145132
v 0.169560 0.558285 0.259110
v -0.000378 0.554590 0.292581
v -0.160919 0.550894 0.258315
v -0.252956 0.548773 0.149623
v -0.254877 0.548773 -0.016813
v -0.159662 0.550893 -0.130791
v 0.001285 0.554590 0.062998
v -0.047120 0.422221 -0.050808
v -0.065994 0.408029 -0.036841
v -0.047500 0.409361 -0.058682
v -0.028533 0.408029 -0.047431
v -0.048405 0.392595 -0.036452
v -0.012866 0.416007 -0.059650
v -0.028468 0.401814 -0.047181
v -0.014249 0.403147 -0.071911
v 0.000402 0.401814 -0.044687
v -0.011445 0.386381 -0.047062
v 0.030061 0.417250 -0.043557
v 0.000328 0.403057 -0.053732
v 0.029752 0.404390 -0.064685
v 0.049385 0.403057 -0.032503
v 0.029530 0.387624 -0.041534
v 0.066976 0.426571 -0.042327
v 0.047296 0.412378 -0.043181
v 0.068255 0.413711 -0.062914
v 0.086812 0.412378 -0.023713
v 0.067029 0.396945 -0.023363
v 0.003520 -0.697040 0.335617
v -0.000901 -0.698334 -0.203617
v -0.000891 -0.085012 -0.202387
v 0.003529 -0.083719 0.336688
v 0.001478 -0.391008 0.511457
v 0.001139 -0.391251 -0.382650
v -0.279717 -0.391952 -0.203732
v -0.283036 -0.083006 0.064187
v -0.282396 -0.392552 0.334870
v -0.484685 -0.389513 0.062935
v -0.283042 -0.696384 0.066340
v 0.291730 -0.391952 -0.201624
v 0.292381 -0.083006 0.065560
v 0.289991 -0.392552 0.336248
v 0.484685 -0.389513 0.065299
v 0.292372 -0.696384 0.067763
v 0.002647 -0.054404 0.229093
v -0.000028 -0.055188 -0.097132
v -0.000022 0.315859 -0.096387
v 0.002652 0.316642 0.229742
v 0.003519 0.130738 0.335466
v -0.000916 0.130590 -0.205437
v -0.223218 0.130166 -0.097433
v -0.225478 0.317073 0.064545
v -0.224656 0.129803 0.228660
v -0.386307 0.131642 0.063546
v -0.225477 -0.054008 0.064545
v 0.232776 0.130166 -0.095791
v 0.233461 0.317073 0.065639
v 0.231723 0.129803 0.229609
v 0.386837 0.131642 0.065432
v 0.233455 -0.054008 0.067397
v 0.013191 0.348254 0.171248
v -0.010570 0.347746 -0.039307
v -0.010516 0.588355 -0.038826
v 0.013238 0.588864 0.171666
v 0.002742 0.468312 0.240721
v 0.000102 0.468217 -0.081293
v -0.129477 0.467941 -0.039679
v -0.111681 0.589143 0.067218
v -0.130931 0.467707 0.170752
v -0.224137 0.468898 0.064553
v -0.130587 0.348511 0.067430
v 0.134939 0.467941 -0.039946
v 0.118317 0.589143 0.064645
v 0.135287 0.467707 0.172040
v 0.225541 0.468898 0.065651
v 0.136322 0.348511 0.064444
v 0.057418 0.542233 -0.035450
v 0.084898 0.521059 -0.034550
v 0.057480 0.523047 -0.054636
v 0.026966 0.521059 -0.051891
v 0.057461 0.498035 -0.048862
v -0.054131 0.542233 -0.039512
v -0.081617 0.521059 -0.038743
v -0.054155 0.523047 -0.058669
v -0.024813 0.521059 -0.055608
v -0.054088 0.498035 -0.052923
v -0.028079 0.468218 -0.070805
v 0.000186 0.442612 -0.071046
v -0.000857 0.468233 -0.198207
v 0.000186 0.492677 -0.071046
v 0.028203 0.468189 -0.071021
v 0.348613 -0.676999 1.305500
v -0.318157 -0.678170 1.304996
v -0.311798 -0.676275 -0.897057
v 0.354180 -0.675103 -0.896441
v 0.326341 -0.633466 -1.070260
v -0.187792 -0.563214 -1.215220
v 0.200594 -0.562043 -1.214885
v -0.297781 -0.634637 -1.070430
v 0.005741 -0.466762 -1.305500
v 0.348613 -0.748668 1.305500
v -0.318157 -0.747804 1.304996
v -0.311798 -0.750539 -0.897057
v 0.354180 -0.751403 -0.896441
v 0.326341 -0.709765 -1.070260
v -0.187792 -0.637479 -1.215220
v 0.200594 -0.638342 -1.214885
v -0.297781 -0.708902 -1.070430
v 0.005741 -0.543061 -1.305500

#684 vt
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.255283 0.257301
vt 0.259445 0.383840
vt 0.479438 0.253145
vt 0.479438 0.253145
vt 0.259445 0.383840
vt 0.485606 0.380324
vt 0.485606 0.380324
vt 0.259006 0.383848
vt 0.480384 0.253127
vt 0.259445 0.383840
vt 0.036638 0.388650
vt 0.264588 0.474695
vt 0.259445 0.383840
vt 0.264588 0.474695
vt 0.485606 0.380324
vt 0.485606 0.380324
vt 0.264588 0.474695
vt 0.259006 0.383848
vt 0.036638 0.388650
vt 0.031458 0.261451
vt 0.259006 0.383848
vt 0.030510 0.261469
vt 0.036638 0.388650
vt 0.259445 0.383840
vt 0.264588 0.474695
vt 0.036638 0.388650
vt 0.259006 0.383848
vt 0.480384 0.253127
vt 0.259006 0.383848
vt 0.255461 0.257298
vt 0.259445 0.383840
vt 0.255283 0.257301
vt 0.030510 0.261469
vt 0.031458 0.261451
vt 0.255461 0.257298
vt 0.259006 0.383848
vt 0.479438 0.253145
vt 0.249984 0.127774
vt 0.255283 0.257301
vt 0.476562 0.122047
vt 0.249984 0.127774
vt 0.479438 0.253145
vt 0.480384 0.253127
vt 0.249545 0.127784
vt 0.476562 0.122047
vt 0.248565 0.041037
vt 0.027127 0.131229
vt 0.249984 0.127774
vt 0.476562 0.122047
vt 0.248565 0.041037
vt 0.249984 0.127774
vt 0.249545 0.127784
vt 0.248565 0.041037
vt 0.476562 0.122047
vt 0.249545 0.127784
vt 0.031458 0.261451
vt 0.027127 0.131229
vt 0.249984 0.127774
vt 0.027127 0.131229
vt 0.030510 0.261469
vt 0.249545 0.127784
vt 0.027127 0.131229
vt 0.248565 0.041037
vt 0.255461 0.257298
vt 0.249545 0.127784
vt 0.480384 0.253127
vt 0.030510 0.261469
vt 0.255283 0.257301
vt 0.249984 0.127774
vt 0.249545 0.127784
vt 0.255461 0.257298
vt 0.031458 0.261451
vt 0.637250 0.250218
vt 0.640668 0.351141
vt 0.772859 0.247703
vt 0.772859 0.247703
vt 0.640668 0.351141
vt 0.777497 0.349144
vt 0.777497 0.349144
vt 0.640403 0.351146
vt 0.773432 0.247693
vt 0.640668 0.351141
vt 0.505880 0.354181
vt 0.644427 0.423611
vt 0.640668 0.351141
vt 0.644427 0.423611
vt 0.777497 0.349144
vt 0.777497 0.349144
vt 0.644427 0.423611
vt 0.640403 0.351146
vt 0.505880 0.354181
vt 0.501841 0.252729
vt 0.640403 0.351146
vt 0.501267 0.252740
vt 0.505880 0.354181
vt 0.640668 0.351141
vt 0.644427 0.423611
vt 0.505880 0.354181
vt 0.640403 0.351146
vt 0.773432 0.247693
vt 0.640403 0.351146
vt 0.637357 0.250216
vt 0.640668 0.351141
vt 0.637250 0.250218
vt 0.501267 0.252740
vt 0.501841 0.252729
vt 0.637357 0.250216
vt 0.640403 0.351146
vt 0.772859 0.247703
vt 0.633122 0.146909
vt 0.637250 0.250218
vt 0.769910 0.143831
vt 0.633122 0.146909
vt 0.772859 0.247703
vt 0.773432 0.247693
vt 0.632856 0.146914
vt 0.769910 0.143831
vt 0.631647 0.077735
vt 0.498294 0.148868
vt 0.633122 0.146909
vt 0.769910 0.143831
vt 0.631647 0.077735
vt 0.633122 0.146909
vt 0.632856 0.146914
vt 0.631647 0.077735
vt 0.769910 0.143831
vt 0.632856 0.146914
vt 0.501841 0.252729
vt 0.498294 0.148868
vt 0.633122 0.146909
vt 0.498294 0.148868
vt 0.501267 0.252740
vt 0.632856 0.146914
vt 0.498294 0.148868
vt 0.631647 0.077735
vt 0.637357 0.250216
vt 0.632856 0.146914
vt 0.773432 0.247693
vt 0.501267 0.252740
vt 0.637250 0.250218
vt 0.633122 0.146909
vt 0.632856 0.146914
vt 0.637357 0.250216
vt 0.501841 0.252729
vt 0.884378 0.245634
vt 0.886346 0.304334
vt 0.972315 0.244004
vt 0.972315 0.244004
vt 0.886346 0.304334
vt 0.976222 0.297094
vt 0.976222 0.297094
vt 0.886174 0.304337
vt 0.972687 0.243998
vt 0.886346 0.304334
vt 0.798939 0.306270
vt 0.888603 0.346483
vt 0.886346 0.304334
vt 0.888603 0.346483
vt 0.976222 0.297094
vt 0.976222 0.297094
vt 0.888603 0.346483
vt 0.886174 0.304337
vt 0.798939 0.306270
vt 0.796571 0.247264
vt 0.886174 0.304337
vt 0.796198 0.247270
vt 0.798939 0.306270
vt 0.886346 0.304334
vt 0.888603 0.346483
vt 0.798939 0.306270
vt 0.886174 0.304337
vt 0.972687 0.243998
vt 0.886174 0.304337
vt 0.884448 0.245633
vt 0.886346 0.304334
vt 0.884378 0.245634
vt 0.796198 0.247270
vt 0.796571 0.247264
vt 0.884448 0.245633
vt 0.886174 0.304337
vt 0.972315 0.244004
vt 0.883325 0.185082
vt 0.884378 0.245634
vt 0.970867 0.189228
vt 0.883325 0.185082
vt 0.972315 0.244004
vt 0.972687 0.243998
vt 0.883295 0.185036
vt 0.970867 0.189228
vt 0.881171 0.145314
vt 0.797737 0.183432
vt 0.883325 0.185082
vt 0.970867 0.189228
vt 0.881171 0.145314
vt 0.883325 0.185082
vt 0.883295 0.185036
vt 0.881171 0.145314
vt 0.970867 0.189228
vt 0.883295 0.185036
vt 0.796571 0.247264
vt 0.797737 0.183432
vt 0.883325 0.185082
vt 0.797737 0.183432
vt 0.796198 0.247270
vt 0.883295 0.185036
vt 0.797737 0.183432
vt 0.881171 0.145314
vt 0.884448 0.245633
vt 0.883295 0.185036
vt 0.972687 0.243998
vt 0.796198 0.247270
vt 0.884378 0.245634
vt 0.883325 0.185082
vt 0.883295 0.185036
vt 0.884448 0.245633
vt 0.796571 0.247264
vt 0.501267 0.252740
vt 0.476562 0.122047
vt 0.479438 0.253145
vt 0.501267 0.252740
vt 0.498294 0.148868
vt 0.476562 0.122047
vt 0.498294 0.148868
vt 0.501841 0.252729
vt 0.476562 0.122047
vt 0.476562 0.122047
vt 0.501841 0.252729
vt 0.480384 0.253127
vt 0.796198 0.247270
vt 0.769910 0.143831
vt 0.772859 0.247703
vt 0.796198 0.247270
vt 0.797737 0.183432
vt 0.769910 0.143831
vt 0.797737 0.183432
vt 0.796571 0.247264
vt 0.769910 0.143831
vt 0.773432 0.247693
vt 0.769910 0.143831
vt 0.796571 0.247264
vt 0.772859 0.247703
vt 0.798939 0.306270
vt 0.796198 0.247270
vt 0.772859 0.247703
vt 0.777497 0.349144
vt 0.798939 0.306270
vt 0.777497 0.349144
vt 0.773432 0.247693
vt 0.798939 0.306270
vt 0.773432 0.247693
vt 0.796571 0.247264
vt 0.798939 0.306270
vt 0.501267 0.252740
vt 0.479438 0.253145
vt 0.505880 0.354181
vt 0.505880 0.354181
vt 0.479438 0.253145
vt 0.485606 0.380324
vt 0.485606 0.380324
vt 0.480384 0.253127
vt 0.505880 0.354181
vt 0.480384 0.253127
vt 0.501841 0.252729
vt 0.505880 0.354181
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.003513 0.509200
vt 0.840187 0.769232
vt 0.003493 0.770762
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.840187 0.769232
vt 0.906199 0.518982
vt 0.840187 0.769232
vt 0.840164 0.507987
vt 0.961114 0.720727
vt 0.906000 0.763800
vt 0.961110 0.568375
vt 0.906000 0.763800
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.961114 0.720727
vt 0.961110 0.568375
vt 0.995478 0.644849
vt 0.906000 0.763800
vt 0.840187 0.769232
vt 0.906199 0.518982
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.003513 0.509200
vt 0.840187 0.769232
vt 0.840164 0.507987
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.840187 0.769232
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.906000 0.763800
vt 0.961114 0.720727
vt 0.961110 0.568375
vt 0.906199 0.518982
vt 0.906000 0.763800
vt 0.995478 0.644849
vt 0.961110 0.568375
vt 0.961114 0.720727
vt 0.906199 0.518982
vt 0.840187 0.769232
vt 0.906000 0.763800
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.840164 0.507987
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.906199 0.518982
vt 0.840164 0.507987
vt 0.906199 0.518982
vt 0.906199 0.518982
vt 0.840164 0.507987
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.961110 0.568375
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.995478 0.644849
vt 0.961110 0.568375
vt 0.995478 0.644849
vt 0.995478 0.644849
vt 0.961110 0.568375
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.840187 0.769232
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.840187 0.769232
vt 0.906000 0.763800
vt 0.906000 0.763800
vt 0.906000 0.763800
vt 0.840187 0.769232
vt 0.906000 0.763800
vt 0.906000 0.763800
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.906000 0.763800
vt 0.995478 0.644849
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.995478 0.644849
vt 0.995478 0.644849
vt 0.003513 0.509200
vt 0.003493 0.770762
vt 0.003513 0.509200
vt 0.003513 0.509200
vt 0.003493 0.770762
vt 0.003493 0.770762

#143 normals
vn -0.031446 0.999506 -0.000087
vn 0.031042 0.671730 -0.740146
vn 0.469392 0.684076 -0.558310
vn 0.742995 0.653217 -0.145828
vn 0.711180 0.625924 0.320066
vn 0.314213 0.610215 0.727261
vn -0.075466 0.579704 0.811325
vn -0.532343 0.611510 0.585377
vn -0.767301 0.624985 0.143677
vn -0.699230 0.650517 -0.296486
vn -0.322442 0.682697 -0.655711
vn -0.052862 0.749282 -0.660137
vn 0.266521 0.765846 -0.585189
vn 0.611860 0.747507 -0.258575
vn 0.664295 0.732409 0.149293
vn 0.430702 0.724046 0.538751
vn 0.014332 0.693230 0.720574
vn -0.322610 0.714168 0.621199
vn -0.647856 0.716377 0.259009
vn -0.666364 0.732565 -0.138951
vn -0.433605 0.755893 -0.490523
vn 0.032978 0.706841 -0.706603
vn 0.379247 0.791239 -0.479701
vn 0.553856 0.822808 -0.127405
vn 0.528119 0.815365 0.237213
vn 0.278022 0.765448 0.580339
vn -0.071847 0.682814 0.727051
vn -0.516675 0.614096 0.596601
vn -0.812550 0.556379 0.173795
vn -0.757645 0.566275 -0.324510
vn -0.360826 0.644773 -0.673850
vn -0.046874 -0.582730 -0.811313
vn 0.403481 -0.474065 -0.782602
vn 0.859891 -0.343495 -0.377623
vn 0.925052 -0.325772 0.195322
vn 0.594280 -0.422606 0.684277
vn 0.077843 -0.546853 0.833602
vn -0.318463 -0.668950 0.671630
vn -0.607210 -0.744329 0.277974
vn -0.641265 -0.754318 -0.140652
vn -0.448757 -0.706220 -0.547604
vn 0.025921 -0.999664 0.000073
vn -0.172254 0.520107 -0.836551
vn -0.791025 -0.168463 -0.588134
vn -0.225475 -0.239993 -0.944227
vn 0.522592 -0.190206 -0.831095
vn -0.166750 -0.783099 -0.599125
vn 0.008137 0.692642 -0.721236
vn -0.833175 -0.121044 -0.539597
vn 0.015024 -0.219552 -0.975486
vn 0.843912 -0.118182 -0.523304
vn 0.011020 -0.830883 -0.556337
vn 0.194964 0.837212 -0.510945
vn -0.578512 0.012200 -0.815580
vn 0.368061 0.022325 -0.929529
vn 0.883673 0.016960 -0.467797
vn 0.232706 -0.788262 -0.569641
vn 0.131557 0.846092 -0.516547
vn -0.779768 -0.130504 -0.612313
vn 0.288854 -0.233094 -0.928563
vn 0.910799 -0.118142 -0.395588
vn 0.143403 -0.912710 -0.382617
vn -0.007381 -0.578764 0.815462
vn -0.002865 -0.580759 -0.814070
vn -0.069344 0.781998 -0.619412
vn -0.074928 0.781251 0.619703
vn -0.008406 -0.003192 0.999957
vn -0.002907 0.001918 -0.999991
vn -0.727877 -0.000562 -0.685704
vn -0.733049 0.680164 -0.004034
vn -0.731826 -0.002031 0.681487
vn -0.999972 -0.000955 -0.007055
vn -0.829882 -0.557923 -0.004042
vn 0.732149 -0.000548 -0.681141
vn 0.628082 0.778147 0.000665
vn 0.728459 -0.002006 0.685084
vn 0.999996 -0.000845 -0.001407
vn 0.833145 -0.553055 0.000572
vn 0.116807 0.145414 0.982451
vn 0.118115 0.148585 -0.981820
vn -0.061467 0.732698 -0.677773
vn -0.065447 0.733725 0.676287
vn -0.007617 -0.002849 0.999964
vn -0.002126 0.001978 -0.999992
vn -0.630414 -0.000949 -0.776257
vn -0.623621 0.781713 -0.004682
vn -0.635289 -0.002203 0.772269
vn -0.999968 -0.001801 -0.007382
vn -0.940999 0.338359 -0.005798
vn 0.636010 -0.000932 -0.771678
vn 0.569663 0.821877 -0.001547
vn 0.632274 -0.002165 0.774739
vn 0.999995 -0.001629 -0.001759
vn 0.982709 -0.185083 0.005328
vn 0.064404 0.127590 0.989735
vn 0.062986 0.178704 -0.981884
vn -0.001579 0.506051 -0.862502
vn -0.006793 0.592709 0.805388
vn -0.007944 -0.002971 0.999962
vn -0.000779 0.002162 -0.999994
vn -0.617125 0.011375 -0.786780
vn -0.765879 0.642958 -0.005809
vn -0.679293 0.009921 0.733798
vn -0.999516 0.030237 -0.007274
vn -0.952465 0.304567 -0.007005
vn 0.623262 0.012648 -0.781909
vn 0.767954 0.640504 -0.001514
vn 0.676308 0.011219 0.736532
vn 0.999444 0.033197 -0.001638
vn 0.996664 -0.081616 0.001640
vn 0.222707 0.689658 -0.689038
vn 0.641462 0.226244 -0.733034
vn 0.290058 0.271349 -0.917735
vn -0.128378 0.272010 -0.953693
vn 0.289750 -0.215477 -0.932531
vn -0.218859 0.689658 -0.690269
vn -0.637367 0.226244 -0.736599
vn -0.284933 0.271349 -0.919339
vn 0.133695 0.272010 -0.952962
vn -0.284543 -0.215477 -0.934133
vn -0.981830 0.010384 -0.189467
vn 0.013802 -0.980215 -0.197452
vn 0.067206 0.061273 -0.995854
vn 0.012269 0.981955 -0.188714
vn 0.984637 0.011964 -0.174192
vn 0.575643 0.577325 0.579079
vn -0.578782 0.577104 0.576162
vn -0.711149 0.700779 0.056351
vn 0.833577 0.552304 -0.010478
vn 0.668740 0.735259 -0.110368
vn -0.676051 0.598047 -0.430460
vn 0.558922 0.794121 -0.238700
vn -0.695922 0.718014 -0.012180
vn 0.000848 0.553517 -0.832838
vn 0.406609 -0.816389 0.410096
vn -0.667821 -0.333370 0.665492
vn -0.449401 -0.885100 -0.120985
vn 0.830260 -0.548119 -0.101162
vn 0.637736 -0.652562 -0.409213
vn -0.521667 -0.384633 -0.761526
vn 0.422537 -0.506169 -0.751835
vn -0.651230 -0.634843 -0.415780
vn 0.001697 -0.160513 -0.987032

#228 faces (verts: 25..167)
usemtl 0x001
s 1
f 26/37/26 25/38/25 27/39/27
usemtl 0x001
s 1
f 27/40/27 25/41/25 28/42/28
usemtl 0x001
s 1
f 28/43/28 25/44/25 29/45/29
usemtl 0x001
s 1
f 29/46/29 25/47/25 30/48/30
usemtl 0x001
s 1
f 30/49/30 25/50/25 31/51/31
usemtl 0x001
s 1
f 31/52/31 25/53/25 32/54/32
usemtl 0x001
s 1
f 32/55/32 25/56/25 33/57/33
usemtl 0x001
s 1
f 33/58/33 25/59/25 34/60/34
usemtl 0x001
s 1
f 34/61/34 25/62/25 35/63/35
usemtl 0x001
s 1
f 35/64/35 25/65/25 26/66/26
usemtl 0x001
s 1
f 36/67/36 26/68/26 37/69/37
usemtl 0x001
s 1
f 37/70/37 26/71/26 27/72/27
usemtl 0x001
s 1
f 37/73/37 27/74/27 38/75/38
usemtl 0x001
s 1
f 38/76/38 27/77/27 28/78/28
usemtl 0x001
s 1
f 38/79/38 28/80/28 39/81/39
usemtl 0x001
s 1
f 39/82/39 28/83/28 29/84/29
usemtl 0x001
s 1
f 39/85/39 29/86/29 40/87/40
usemtl 0x001
s 1
f 40/88/40 29/89/29 30/90/30
usemtl 0x001
s 1
f 40/91/40 30/92/30 41/93/41
usemtl 0x001
s 1
f 41/94/41 30/95/30 31/96/31
usemtl 0x001
s 1
f 41/97/41 31/98/31 42/99/42
usemtl 0x001
s 1
f 42/100/42 31/101/31 32/102/32
usemtl 0x001
s 1
f 42/103/42 32/104/32 43/105/43
usemtl 0x001
s 1
f 43/106/43 32/107/32 33/108/33
usemtl 0x001
s 1
f 43/109/43 33/110/33 44/111/44
usemtl 0x001
s 1
f 44/112/44 33/113/33 34/114/34
usemtl 0x001
s 1
f 44/115/44 34/116/34 45/117/45
usemtl 0x001
s 1
f 45/118/45 34/119/34 35/120/35
usemtl 0x001
s 1
f 45/121/45 35/122/35 36/123/36
usemtl 0x001
s 1
f 36/124/36 35/125/35 26/126/26
usemtl 0x001
s 1
f 46/127/46 36/128/36 47/129/47
usemtl 0x001
s 1
f 47/130/47 36/131/36 37/132/37
usemtl 0x001
s 1
f 47/133/47 37/134/37 48/135/48
usemtl 0x001
s 1
f 48/136/48 37/137/37 38/138/38
usemtl 0x001
s 1
f 48/139/48 38/140/38 49/141/49
usemtl 0x001
s 1
f 49/142/49 38/143/38 39/144/39
usemtl 0x001
s 1
f 49/145/49 39/146/39 50/147/50
usemtl 0x001
s 1
f 50/148/50 39/149/39 40/150/40
usemtl 0x001
s 1
f 50/151/50 40/152/40 51/153/51
usemtl 0x001
s 1
f 51/154/51 40/155/40 41/156/41
usemtl 0x001
s 1
f 51/157/51 41/158/41 52/159/52
usemtl 0x001
s 1
f 52/160/52 41/161/41 42/162/42
usemtl 0x001
s 1
f 52/163/52 42/164/42 53/165/53
usemtl 0x001
s 1
f 53/166/53 42/167/42 43/168/43
usemtl 0x001
s 1
f 53/169/53 43/170/43 54/171/54
usemtl 0x001
s 1
f 54/172/54 43/173/43 44/174/44
usemtl 0x001
s 1
f 54/175/54 44/176/44 55/177/55
usemtl 0x001
s 1
f 55/178/55 44/179/44 45/180/45
usemtl 0x001
s 1
f 55/181/55 45/182/45 46/183/46
usemtl 0x001
s 1
f 46/184/46 45/185/45 36/186/36
usemtl 0x001
s 1
f 56/187/56 46/188/46 57/189/57
usemtl 0x001
s 1
f 57/190/57 46/191/46 47/192/47
usemtl 0x001
s 1
f 57/193/57 47/194/47 58/195/58
usemtl 0x001
s 1
f 58/196/58 47/197/47 48/198/48
usemtl 0x001
s 1
f 58/199/58 48/200/48 59/201/59
usemtl 0x001
s 1
f 59/202/59 48/203/48 49/204/49
usemtl 0x001
s 1
f 59/205/59 49/206/49 60/207/60
usemtl 0x001
s 1
f 60/208/60 49/209/49 50/210/50
usemtl 0x001
s 1
f 60/211/60 50/212/50 61/213/61
usemtl 0x001
s 1
f 61/214/61 50/215/50 51/216/51
usemtl 0x001
s 1
f 61/217/61 51/218/51 62/219/62
usemtl 0x001
s 1
f 62/220/62 51/221/51 52/222/52
usemtl 0x001
s 1
f 62/223/62 52/224/52 63/225/63
usemtl 0x001
s 1
f 63/226/63 52/227/52 53/228/53
usemtl 0x001
s 1
f 63/229/63 53/230/53 64/231/64
usemtl 0x001
s 1
f 64/232/64 53/233/53 54/234/54
usemtl 0x001
s 1
f 64/235/64 54/236/54 65/237/65
usemtl 0x001
s 1
f 65/238/65 54/239/54 55/240/55
usemtl 0x001
s 1
f 65/241/65 55/242/55 56/243/56
usemtl 0x001
s 1
f 56/244/56 55/245/55 46/246/46
usemtl 0x001
s 1
f 64/247/64 66/248/66 63/249/63
usemtl 0x001
s 1
f 65/250/65 66/251/66 64/252/64
usemtl 0x001
s 1
f 56/253/56 66/254/66 65/255/65
usemtl 0x001
s 1
f 57/256/57 66/257/66 56/258/56
usemtl 0x001
s 1
f 58/259/58 66/260/66 57/261/57
usemtl 0x001
s 1
f 59/262/59 66/263/66 58/264/58
usemtl 0x001
s 1
f 60/265/60 66/266/66 59/267/59
usemtl 0x001
s 1
f 61/268/61 66/269/66 60/270/60
usemtl 0x001
s 1
f 62/271/62 66/272/66 61/273/61
usemtl 0x001
s 1
f 63/274/63 66/275/66 62/276/62
usemtl 0x001
s 1
f 69/277/69 68/278/68 67/279/67
usemtl 0x001
s 1
f 70/280/70 69/281/69 67/282/67
usemtl 0x001
s 1
f 68/283/68 69/284/69 71/285/71
usemtl 0x001
s 1
f 69/286/69 70/287/70 71/288/71
usemtl 0x001
s 1
f 74/289/74 73/290/73 72/291/72
usemtl 0x001
s 1
f 75/292/75 74/293/74 72/294/72
usemtl 0x001
s 1
f 73/295/73 74/296/74 76/297/76
usemtl 0x001
s 1
f 74/298/74 75/299/75 76/300/76
usemtl 0x001
s 1
f 79/301/79 78/302/78 77/303/77
usemtl 0x001
s 1
f 80/304/80 79/305/79 77/306/77
usemtl 0x001
s 1
f 78/307/78 79/308/79 81/309/81
usemtl 0x001
s 1
f 79/310/79 80/311/80 81/312/81
usemtl 0x001
s 1
f 84/313/84 83/314/83 82/315/82
usemtl 0x001
s 1
f 85/316/85 84/317/84 82/318/82
usemtl 0x001
s 1
f 83/319/83 84/320/84 86/321/86
usemtl 0x001
s 1
f 84/322/84 85/323/85 86/324/86
usemtl 0x001
s 1
f 92/325/92 93/326/93 89/327/89
usemtl 0x001
s 1
f 89/328/89 93/329/93 94/330/94
usemtl 0x001
s 1
f 94/331/94 95/332/95 90/333/90
usemtl 0x001
s 1
f 93/334/93 97/335/97 96/336/96
usemtl 0x001
s 1
f 93/337/93 96/338/96 94/339/94
usemtl 0x001
s 1
f 94/340/94 96/341/96 95/342/95
usemtl 0x001
s 1
f 97/343/97 87/344/87 95/345/95
usemtl 0x001
s 1
f 88/346/88 97/347/97 93/348/93
usemtl 0x001
s 1
f 96/349/96 97/350/97 95/351/95
usemtl 0x001
s 1
f 90/352/90 95/353/95 91/354/91
usemtl 0x001
s 1
f 93/355/93 92/356/92 88/357/88
usemtl 0x001
s 1
f 87/358/87 91/359/91 95/360/95
usemtl 0x001
s 1
f 89/361/89 98/362/98 92/363/92
usemtl 0x001
s 1
f 99/364/99 98/365/98 89/366/89
usemtl 0x001
s 1
f 90/367/90 100/368/100 99/369/99
usemtl 0x001
s 1
f 101/370/101 102/371/102 98/372/98
usemtl 0x001
s 1
f 99/373/99 101/374/101 98/375/98
usemtl 0x001
s 1
f 100/376/100 101/377/101 99/378/99
usemtl 0x001
s 1
f 100/379/100 87/380/87 102/381/102
usemtl 0x001
s 1
f 98/382/98 102/383/102 88/384/88
usemtl 0x001
s 1
f 100/385/100 102/386/102 101/387/101
usemtl 0x001
s 1
f 91/388/91 100/389/100 90/390/90
usemtl 0x001
s 1
f 88/391/88 92/392/92 98/393/98
usemtl 0x001
s 1
f 100/394/100 91/395/91 87/396/87
usemtl 0x001
s 1
f 108/397/108 109/398/109 105/399/105
usemtl 0x001
s 1
f 105/400/105 109/401/109 110/402/110
usemtl 0x001
s 1
f 110/403/110 111/404/111 106/405/106
usemtl 0x001
s 1
f 109/406/109 113/407/113 112/408/112
usemtl 0x001
s 1
f 109/409/109 112/410/112 110/411/110
usemtl 0x001
s 1
f 110/412/110 112/413/112 111/414/111
usemtl 0x001
s 1
f 113/415/113 103/416/103 111/417/111
usemtl 0x001
s 1
f 104/418/104 113/419/113 109/420/109
usemtl 0x001
s 1
f 112/421/112 113/422/113 111/423/111
usemtl 0x001
s 1
f 106/424/106 111/425/111 107/426/107
usemtl 0x001
s 1
f 109/427/109 108/428/108 104/429/104
usemtl 0x001
s 1
f 103/430/103 107/431/107 111/432/111
usemtl 0x001
s 1
f 105/433/105 114/434/114 108/435/108
usemtl 0x001
s 1
f 115/436/115 114/437/114 105/438/105
usemtl 0x001
s 1
f 106/439/106 116/440/116 115/441/115
usemtl 0x001
s 1
f 117/442/117 118/443/118 114/444/114
usemtl 0x001
s 1
f 115/445/115 117/446/117 114/447/114
usemtl 0x001
s 1
f 116/448/116 117/449/117 115/450/115
usemtl 0x001
s 1
f 116/451/116 103/452/103 118/453/118
usemtl 0x001
s 1
f 114/454/114 118/455/118 104/456/104
usemtl 0x001
s 1
f 116/457/116 118/458/118 117/459/117
usemtl 0x001
s 1
f 107/460/107 116/461/116 106/462/106
usemtl 0x001
s 1
f 104/463/104 108/464/108 114/465/114
usemtl 0x001
s 1
f 116/466/116 107/467/107 103/468/103
usemtl 0x001
s 1
f 124/469/124 125/470/125 121/471/121
usemtl 0x001
s 1
f 121/472/121 125/473/125 126/474/126
usemtl 0x001
s 1
f 126/475/126 127/476/127 122/477/122
usemtl 0x001
s 1
f 125/478/125 129/479/129 128/480/128
usemtl 0x001
s 1
f 125/481/125 128/482/128 126/483/126
usemtl 0x001
s 1
f 126/484/126 128/485/128 127/486/127
usemtl 0x001
s 1
f 129/487/129 119/488/119 127/489/127
usemtl 0x001
s 1
f 120/490/120 129/491/129 125/492/125
usemtl 0x001
s 1
f 128/493/128 129/494/129 127/495/127
usemtl 0x001
s 1
f 122/496/122 127/497/127 123/498/123
usemtl 0x001
s 1
f 125/499/125 124/500/124 120/501/120
usemtl 0x001
s 1
f 119/502/119 123/503/123 127/504/127
usemtl 0x001
s 1
f 121/505/121 130/506/130 124/507/124
usemtl 0x001
s 1
f 131/508/131 130/509/130 121/510/121
usemtl 0x001
s 1
f 122/511/122 132/512/132 131/513/131
usemtl 0x001
s 1
f 133/514/133 134/515/134 130/516/130
usemtl 0x001
s 1
f 131/517/131 133/518/133 130/519/130
usemtl 0x001
s 1
f 132/520/132 133/521/133 131/522/131
usemtl 0x001
s 1
f 132/523/132 119/524/119 134/525/134
usemtl 0x001
s 1
f 130/526/130 134/527/134 120/528/120
usemtl 0x001
s 1
f 132/529/132 134/530/134 133/531/133
usemtl 0x001
s 1
f 123/532/123 132/533/132 122/534/122
usemtl 0x001
s 1
f 120/535/120 124/536/124 130/537/130
usemtl 0x001
s 1
f 132/538/132 123/539/123 119/540/119
usemtl 0x001
s 1
f 104/541/104 99/542/99 89/543/89
usemtl 0x001
s 1
f 104/544/104 118/545/118 99/546/99
usemtl 0x001
s 1
f 118/547/118 103/548/103 99/549/99
usemtl 0x001
s 1
f 99/550/99 103/551/103 90/552/90
usemtl 0x001
s 1
f 120/553/120 115/554/115 105/555/105
usemtl 0x001
s 1
f 120/556/120 134/557/134 115/558/115
usemtl 0x001
s 1
f 134/559/134 119/560/119 115/561/115
usemtl 0x001
s 1
f 106/562/106 115/563/115 119/564/119
usemtl 0x001
s 1
f 105/565/105 129/566/129 120/567/120
usemtl 0x001
s 1
f 105/568/105 110/569/110 129/570/129
usemtl 0x001
s 1
f 110/571/110 106/572/106 129/573/129
usemtl 0x001
s 1
f 106/574/106 119/575/119 129/576/129
usemtl 0x001
s 1
f 104/577/104 89/578/89 113/579/113
usemtl 0x001
s 1
f 113/580/113 89/581/89 94/582/94
usemtl 0x001
s 1
f 94/583/94 90/584/90 113/585/113
usemtl 0x001
s 1
f 90/586/90 103/587/103 113/588/113
usemtl 0x001
s 1
f 135/589/135 136/590/136 137/591/137
usemtl 0x001
s 1
f 135/592/135 137/593/137 138/594/138
usemtl 0x001
s 1
f 139/595/139 137/596/137 136/597/136
usemtl 0x001
s 1
f 139/598/139 138/599/138 137/600/137
usemtl 0x001
s 1
f 142/601/142 141/602/141 140/603/140
usemtl 0x001
s 1
f 143/604/143 142/605/142 140/606/140
usemtl 0x001
s 1
f 141/607/141 142/608/142 144/609/144
usemtl 0x001
s 1
f 142/610/142 143/611/143 144/612/144
usemtl 0x001
s 1
f 145/613/145 147/614/147 146/615/146
usemtl 0x001
s 1
f 145/616/145 148/617/148 147/618/147
usemtl 0x001
s 1
f 149/619/149 147/620/147 148/621/148
usemtl 0x001
s 1
f 149/622/149 146/623/146 147/624/147
usemtl 0x000
s 1
f 150/625/150 152/626/152 151/627/151
usemtl 0x000
s 1
f 150/628/150 153/629/153 152/630/152
usemtl 0x000
s 1
f 154/631/154 152/632/152 153/633/153
usemtl 0x000
s 1
f 155/634/155 157/635/157 156/636/156
usemtl 0x000
s 1
f 157/637/157 154/638/154 156/639/156
usemtl 0x000
s 1
f 155/640/155 156/641/156 158/642/158
usemtl 0x000
s 1
f 157/643/157 152/644/152 154/645/154
usemtl 0x000
s 1
f 160/646/160 161/647/161 159/648/159
usemtl 0x000
s 1
f 161/649/161 162/650/162 159/651/159
usemtl 0x000
s 1
f 162/652/162 161/653/161 163/654/163
usemtl 0x000
s 1
f 165/655/165 166/656/166 164/657/164
usemtl 0x000
s 1
f 165/658/165 163/659/163 166/660/166
usemtl 0x000
s 1
f 167/661/167 165/662/165 164/663/164
usemtl 0x000
s 1
f 163/664/163 161/665/161 166/666/166
usemtl 0x000
s 1
f 159/667/159 162/668/162 150/669/150
usemtl 0x000
s 1
f 162/670/162 153/671/153 150/672/150
usemtl 0x000
s 1
f 162/673/162 163/674/163 153/675/153
usemtl 0x000
s 1
f 163/676/163 154/677/154 153/678/153
usemtl 0x000
s 1
f 163/679/163 165/680/165 154/681/154
usemtl 0x000
s 1
f 165/682/165 156/683/156 154/684/154
usemtl 0x000
s 1
f 165/685/165 167/686/167 156/687/156
usemtl 0x000
s 1
f 167/688/167 158/689/158 156/690/156
usemtl 0x000
s 1
f 160/691/160 152/692/152 161/693/161
usemtl 0x000
s 1
f 151/694/151 152/695/152 160/696/160
usemtl 0x000
s 1
f 161/697/161 152/698/152 166/699/166
usemtl 0x000
s 1
f 157/700/157 166/701/166 152/702/152
usemtl 0x000
s 1
f 166/703/166 157/704/157 164/705/164
usemtl 0x000
s 1
f 155/706/155 164/707/164 157/708/157
usemtl 0x000
s 1
f 167/709/167 164/710/164 155/711/155
usemtl 0x000
s 1
f 155/712/155 158/713/158 167/714/167
usemtl 0x000
s 1
f 150/715/150 160/716/160 159/717/159
usemtl 0x000
s 1
f 150/718/150 151/719/151 160/720/160


o DAMAGE_:HB
#part position 0.000000 0.000000 -0.000000

#143 verts
v 0.015465 0.741107 0.059659
v -0.008335 0.748319 -0.019506
v 0.074838 0.750324 -0.008219
v 0.109403 0.751403 0.030385
v 0.113263 0.751403 0.118447
v 0.073610 0.750324 0.168350
v 0.014029 0.748319 0.178678
v -0.073548 0.746314 0.167690
v -0.112178 0.745237 0.118123
v -0.111564 0.745237 0.039454
v -0.072413 0.746314 -0.009051
v -0.011870 0.573638 -0.050829
v 0.084814 0.575917 -0.037025
v 0.130749 0.577163 0.020229
v 0.130834 0.577163 0.108571
v 0.084156 0.575917 0.166384
v 0.002247 0.573638 0.180336
v -0.085535 0.571362 0.165976
v -0.131146 0.570114 0.109539
v -0.131556 0.570114 0.020380
v -0.084878 0.571362 -0.037433
v 0.003023 0.566945 -0.164266
v 0.165135 0.570568 -0.130010
v 0.258395 0.572346 -0.018642
v 0.259203 0.572346 0.145119
v 0.163876 0.570568 0.259096
v -0.000378 0.566945 0.292566
v -0.166602 0.563324 0.258301
v -0.257967 0.561244 0.151271
v -0.260628 0.561244 -0.016666
v -0.166330 0.563324 -0.130181
v 0.003023 0.554590 -0.164280
v 0.170818 0.558285 -0.129997
v 0.263285 0.560410 -0.020252
v 0.264775 0.560410 0.145132
v 0.169560 0.558285 0.259110
v -0.000378 0.554590 0.292581
v -0.160919 0.550894 0.258315
v -0.252956 0.548773 0.149623
v -0.254877 0.548773 -0.016813
v -0.159662 0.550893 -0.130791
v 0.001285 0.554590 0.062998
v -0.047120 0.422221 -0.050808
v -0.065994 0.408029 -0.036841
v -0.047500 0.409361 -0.058682
v -0.028533 0.408029 -0.047431
v -0.048405 0.392595 -0.036452
v -0.012866 0.416007 -0.059650
v -0.028468 0.401814 -0.047181
v -0.014249 0.403147 -0.071911
v 0.000402 0.401814 -0.044687
v -0.011445 0.386381 -0.047062
v 0.030061 0.417250 -0.043557
v 0.000328 0.403057 -0.053732
v 0.029752 0.404390 -0.064685
v 0.049385 0.403057 -0.032503
v 0.029530 0.387624 -0.041534
v 0.066976 0.426571 -0.042327
v 0.047296 0.412378 -0.043181
v 0.068255 0.413711 -0.062914
v 0.086812 0.412378 -0.023713
v 0.067029 0.396945 -0.023363
v 0.003520 -0.697040 0.335617
v -0.000901 -0.698334 -0.203617
v -0.000891 -0.085012 -0.202387
v 0.003529 -0.083719 0.336688
v 0.001478 -0.391008 0.511457
v 0.001139 -0.391251 -0.382650
v -0.279717 -0.391952 -0.203732
v -0.283036 -0.083006 0.064187
v -0.282396 -0.392552 0.334870
v -0.484685 -0.389513 0.062935
v -0.283042 -0.696384 0.066340
v 0.291730 -0.391952 -0.201624
v 0.292381 -0.083006 0.065560
v 0.289991 -0.392552 0.336248
v 0.484685 -0.389513 0.065299
v 0.292372 -0.696384 0.067763
v 0.002647 -0.054404 0.229093
v -0.000028 -0.055188 -0.097132
v -0.000022 0.315859 -0.096387
v 0.002652 0.316642 0.229742
v 0.003519 0.130738 0.335466
v -0.000916 0.130590 -0.205437
v -0.223218 0.130166 -0.097433
v -0.225478 0.317073 0.064545
v -0.224656 0.129803 0.228660
v -0.386307 0.131642 0.063546
v -0.225477 -0.054008 0.064545
v 0.232776 0.130166 -0.095791
v 0.233461 0.317073 0.065639
v 0.231723 0.129803 0.229609
v 0.386837 0.131642 0.065432
v 0.233455 -0.054008 0.067397
v 0.013191 0.348254 0.171248
v -0.010570 0.347746 -0.039307
v -0.010516 0.588355 -0.038826
v 0.013238 0.588864 0.171666
v 0.002742 0.468312 0.240721
v 0.000102 0.468217 -0.081293
v -0.129477 0.467941 -0.039679
v -0.111681 0.589143 0.067218
v -0.130931 0.467707 0.170752
v -0.224137 0.468898 0.064553
v -0.130587 0.348511 0.067430
v 0.134939 0.467941 -0.039946
v 0.118317 0.589143 0.064645
v 0.135287 0.467707 0.172040
v 0.225541 0.468898 0.065651
v 0.136322 0.348511 0.064444
v 0.057418 0.542233 -0.035450
v 0.084898 0.521059 -0.034550
v 0.057480 0.523047 -0.054636
v 0.026966 0.521059 -0.051891
v 0.057461 0.498035 -0.048862
v -0.054131 0.542233 -0.039512
v -0.081617 0.521059 -0.038743
v -0.054155 0.523047 -0.058669
v -0.024813 0.521059 -0.055608
v -0.054088 0.498035 -0.052923
v -0.028079 0.468218 -0.070805
v 0.000186 0.442612 -0.071046
v -0.000857 0.468233 -0.198207
v 0.000186 0.492677 -0.071046
v 0.028203 0.468189 -0.071021
v 0.348613 -0.676999 1.305500
v -0.318157 -0.678170 1.304996
v -0.311798 -0.676275 -0.897057
v 0.354180 -0.675103 -0.896441
v 0.326341 -0.633466 -1.070260
v -0.187792 -0.563214 -1.215220
v 0.200594 -0.562043 -1.214885
v -0.297781 -0.634637 -1.070430
v 0.005741 -0.466762 -1.305500
v 0.348613 -0.748668 1.305500
v -0.318157 -0.747804 1.304996
v -0.311798 -0.750539 -0.897057
v 0.354180 -0.751403 -0.896441
v 0.326341 -0.709765 -1.070260
v -0.187792 -0.637479 -1.215220
v 0.200594 -0.638342 -1.214885
v -0.297781 -0.708902 -1.070430
v 0.005741 -0.543061 -1.305500

#684 vt
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.230000 0.960000
vt 0.235000 0.885000
vt 0.325000 0.970000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.255283 0.257301
vt 0.259445 0.383840
vt 0.479438 0.253145
vt 0.479438 0.253145
vt 0.259445 0.383840
vt 0.485606 0.380324
vt 0.485606 0.380324
vt 0.259006 0.383848
vt 0.480384 0.253127
vt 0.259445 0.383840
vt 0.036638 0.388650
vt 0.264588 0.474695
vt 0.259445 0.383840
vt 0.264588 0.474695
vt 0.485606 0.380324
vt 0.485606 0.380324
vt 0.264588 0.474695
vt 0.259006 0.383848
vt 0.036638 0.388650
vt 0.031458 0.261451
vt 0.259006 0.383848
vt 0.030510 0.261469
vt 0.036638 0.388650
vt 0.259445 0.383840
vt 0.264588 0.474695
vt 0.036638 0.388650
vt 0.259006 0.383848
vt 0.480384 0.253127
vt 0.259006 0.383848
vt 0.255461 0.257298
vt 0.259445 0.383840
vt 0.255283 0.257301
vt 0.030510 0.261469
vt 0.031458 0.261451
vt 0.255461 0.257298
vt 0.259006 0.383848
vt 0.479438 0.253145
vt 0.249984 0.127774
vt 0.255283 0.257301
vt 0.476562 0.122047
vt 0.249984 0.127774
vt 0.479438 0.253145
vt 0.480384 0.253127
vt 0.249545 0.127784
vt 0.476562 0.122047
vt 0.248565 0.041037
vt 0.027127 0.131229
vt 0.249984 0.127774
vt 0.476562 0.122047
vt 0.248565 0.041037
vt 0.249984 0.127774
vt 0.249545 0.127784
vt 0.248565 0.041037
vt 0.476562 0.122047
vt 0.249545 0.127784
vt 0.031458 0.261451
vt 0.027127 0.131229
vt 0.249984 0.127774
vt 0.027127 0.131229
vt 0.030510 0.261469
vt 0.249545 0.127784
vt 0.027127 0.131229
vt 0.248565 0.041037
vt 0.255461 0.257298
vt 0.249545 0.127784
vt 0.480384 0.253127
vt 0.030510 0.261469
vt 0.255283 0.257301
vt 0.249984 0.127774
vt 0.249545 0.127784
vt 0.255461 0.257298
vt 0.031458 0.261451
vt 0.637250 0.250218
vt 0.640668 0.351141
vt 0.772859 0.247703
vt 0.772859 0.247703
vt 0.640668 0.351141
vt 0.777497 0.349144
vt 0.777497 0.349144
vt 0.640403 0.351146
vt 0.773432 0.247693
vt 0.640668 0.351141
vt 0.505880 0.354181
vt 0.644427 0.423611
vt 0.640668 0.351141
vt 0.644427 0.423611
vt 0.777497 0.349144
vt 0.777497 0.349144
vt 0.644427 0.423611
vt 0.640403 0.351146
vt 0.505880 0.354181
vt 0.501841 0.252729
vt 0.640403 0.351146
vt 0.501267 0.252740
vt 0.505880 0.354181
vt 0.640668 0.351141
vt 0.644427 0.423611
vt 0.505880 0.354181
vt 0.640403 0.351146
vt 0.773432 0.247693
vt 0.640403 0.351146
vt 0.637357 0.250216
vt 0.640668 0.351141
vt 0.637250 0.250218
vt 0.501267 0.252740
vt 0.501841 0.252729
vt 0.637357 0.250216
vt 0.640403 0.351146
vt 0.772859 0.247703
vt 0.633122 0.146909
vt 0.637250 0.250218
vt 0.769910 0.143831
vt 0.633122 0.146909
vt 0.772859 0.247703
vt 0.773432 0.247693
vt 0.632856 0.146914
vt 0.769910 0.143831
vt 0.631647 0.077735
vt 0.498294 0.148868
vt 0.633122 0.146909
vt 0.769910 0.143831
vt 0.631647 0.077735
vt 0.633122 0.146909
vt 0.632856 0.146914
vt 0.631647 0.077735
vt 0.769910 0.143831
vt 0.632856 0.146914
vt 0.501841 0.252729
vt 0.498294 0.148868
vt 0.633122 0.146909
vt 0.498294 0.148868
vt 0.501267 0.252740
vt 0.632856 0.146914
vt 0.498294 0.148868
vt 0.631647 0.077735
vt 0.637357 0.250216
vt 0.632856 0.146914
vt 0.773432 0.247693
vt 0.501267 0.252740
vt 0.637250 0.250218
vt 0.633122 0.146909
vt 0.632856 0.146914
vt 0.637357 0.250216
vt 0.501841 0.252729
vt 0.884378 0.245634
vt 0.886346 0.304334
vt 0.972315 0.244004
vt 0.972315 0.244004
vt 0.886346 0.304334
vt 0.976222 0.297094
vt 0.976222 0.297094
vt 0.886174 0.304337
vt 0.972687 0.243998
vt 0.886346 0.304334
vt 0.798939 0.306270
vt 0.888603 0.346483
vt 0.886346 0.304334
vt 0.888603 0.346483
vt 0.976222 0.297094
vt 0.976222 0.297094
vt 0.888603 0.346483
vt 0.886174 0.304337
vt 0.798939 0.306270
vt 0.796571 0.247264
vt 0.886174 0.304337
vt 0.796198 0.247270
vt 0.798939 0.306270
vt 0.886346 0.304334
vt 0.888603 0.346483
vt 0.798939 0.306270
vt 0.886174 0.304337
vt 0.972687 0.243998
vt 0.886174 0.304337
vt 0.884448 0.245633
vt 0.886346 0.304334
vt 0.884378 0.245634
vt 0.796198 0.247270
vt 0.796571 0.247264
vt 0.884448 0.245633
vt 0.886174 0.304337
vt 0.972315 0.244004
vt 0.883325 0.185082
vt 0.884378 0.245634
vt 0.970867 0.189228
vt 0.883325 0.185082
vt 0.972315 0.244004
vt 0.972687 0.243998
vt 0.883295 0.185036
vt 0.970867 0.189228
vt 0.881171 0.145314
vt 0.797737 0.183432
vt 0.883325 0.185082
vt 0.970867 0.189228
vt 0.881171 0.145314
vt 0.883325 0.185082
vt 0.883295 0.185036
vt 0.881171 0.145314
vt 0.970867 0.189228
vt 0.883295 0.185036
vt 0.796571 0.247264
vt 0.797737 0.183432
vt 0.883325 0.185082
vt 0.797737 0.183432
vt 0.796198 0.247270
vt 0.883295 0.185036
vt 0.797737 0.183432
vt 0.881171 0.145314
vt 0.884448 0.245633
vt 0.883295 0.185036
vt 0.972687 0.243998
vt 0.796198 0.247270
vt 0.884378 0.245634
vt 0.883325 0.185082
vt 0.883295 0.185036
vt 0.884448 0.245633
vt 0.796571 0.247264
vt 0.501267 0.252740
vt 0.476562 0.122047
vt 0.479438 0.253145
vt 0.501267 0.252740
vt 0.498294 0.148868
vt 0.476562 0.122047
vt 0.498294 0.148868
vt 0.501841 0.252729
vt 0.476562 0.122047
vt 0.476562 0.122047
vt 0.501841 0.252729
vt 0.480384 0.253127
vt 0.796198 0.247270
vt 0.769910 0.143831
vt 0.772859 0.247703
vt 0.796198 0.247270
vt 0.797737 0.183432
vt 0.769910 0.143831
vt 0.797737 0.183432
vt 0.796571 0.247264
vt 0.769910 0.143831
vt 0.773432 0.247693
vt 0.769910 0.143831
vt 0.796571 0.247264
vt 0.772859 0.247703
vt 0.798939 0.306270
vt 0.796198 0.247270
vt 0.772859 0.247703
vt 0.777497 0.349144
vt 0.798939 0.306270
vt 0.777497 0.349144
vt 0.773432 0.247693
vt 0.798939 0.306270
vt 0.773432 0.247693
vt 0.796571 0.247264
vt 0.798939 0.306270
vt 0.501267 0.252740
vt 0.479438 0.253145
vt 0.505880 0.354181
vt 0.505880 0.354181
vt 0.479438 0.253145
vt 0.485606 0.380324
vt 0.485606 0.380324
vt 0.480384 0.253127
vt 0.505880 0.354181
vt 0.480384 0.253127
vt 0.501841 0.252729
vt 0.505880 0.354181
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.225000 0.985000
vt 0.255000 0.905000
vt 0.285000 0.975000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.050000 0.950000
vt 0.085000 0.845000
vt 0.140000 0.960000
vt 0.003513 0.509200
vt 0.840187 0.769232
vt 0.003493 0.770762
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.840187 0.769232
vt 0.906199 0.518982
vt 0.840187 0.769232
vt 0.840164 0.507987
vt 0.961114 0.720727
vt 0.906000 0.763800
vt 0.961110 0.568375
vt 0.906000 0.763800
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.961114 0.720727
vt 0.961110 0.568375
vt 0.995478 0.644849
vt 0.906000 0.763800
vt 0.840187 0.769232
vt 0.906199 0.518982
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.003513 0.509200
vt 0.840187 0.769232
vt 0.840164 0.507987
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.840187 0.769232
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.906000 0.763800
vt 0.961114 0.720727
vt 0.961110 0.568375
vt 0.906199 0.518982
vt 0.906000 0.763800
vt 0.995478 0.644849
vt 0.961110 0.568375
vt 0.961114 0.720727
vt 0.906199 0.518982
vt 0.840187 0.769232
vt 0.906000 0.763800
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.840164 0.507987
vt 0.003513 0.509200
vt 0.840164 0.507987
vt 0.906199 0.518982
vt 0.840164 0.507987
vt 0.906199 0.518982
vt 0.906199 0.518982
vt 0.840164 0.507987
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.961110 0.568375
vt 0.906199 0.518982
vt 0.961110 0.568375
vt 0.995478 0.644849
vt 0.961110 0.568375
vt 0.995478 0.644849
vt 0.995478 0.644849
vt 0.961110 0.568375
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.840187 0.769232
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.003493 0.770762
vt 0.840187 0.769232
vt 0.840187 0.769232
vt 0.906000 0.763800
vt 0.906000 0.763800
vt 0.906000 0.763800
vt 0.840187 0.769232
vt 0.906000 0.763800
vt 0.906000 0.763800
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.906000 0.763800
vt 0.995478 0.644849
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.961114 0.720727
vt 0.995478 0.644849
vt 0.995478 0.644849
vt 0.003513 0.509200
vt 0.003493 0.770762
vt 0.003513 0.509200
vt 0.003513 0.509200
vt 0.003493 0.770762
vt 0.003493 0.770762

#143 normals
vn -0.031446 0.999506 -0.000087
vn 0.031042 0.671730 -0.740146
vn 0.469392 0.684076 -0.558310
vn 0.742995 0.653217 -0.145828
vn 0.711180 0.625924 0.320066
vn 0.314213 0.610215 0.727261
vn -0.075466 0.579704 0.811325
vn -0.532343 0.611510 0.585377
vn -0.767301 0.624985 0.143677
vn -0.699230 0.650517 -0.296486
vn -0.322442 0.682697 -0.655711
vn -0.052862 0.749282 -0.660137
vn 0.266521 0.765846 -0.585189
vn 0.611860 0.747507 -0.258575
vn 0.664295 0.732409 0.149293
vn 0.430702 0.724046 0.538751
vn 0.014332 0.693230 0.720574
vn -0.322610 0.714168 0.621199
vn -0.647856 0.716377 0.259009
vn -0.666364 0.732565 -0.138951
vn -0.433605 0.755893 -0.490523
vn 0.032978 0.706841 -0.706603
vn 0.379247 0.791239 -0.479701
vn 0.553856 0.822808 -0.127405
vn 0.528119 0.815365 0.237213
vn 0.278022 0.765448 0.580339
vn -0.071847 0.682814 0.727051
vn -0.516675 0.614096 0.596601
vn -0.812550 0.556379 0.173795
vn -0.757645 0.566275 -0.324510
vn -0.360826 0.644773 -0.673850
vn -0.046874 -0.582730 -0.811313
vn 0.403481 -0.474065 -0.782602
vn 0.859891 -0.343495 -0.377623
vn 0.925052 -0.325772 0.195322
vn 0.594280 -0.422606 0.684277
vn 0.077843 -0.546853 0.833602
vn -0.318463 -0.668950 0.671630
vn -0.607210 -0.744329 0.277974
vn -0.641265 -0.754318 -0.140652
vn -0.448757 -0.706220 -0.547604
vn 0.025921 -0.999664 0.000073
vn -0.172254 0.520107 -0.836551
vn -0.791025 -0.168463 -0.588134
vn -0.225475 -0.239993 -0.944227
vn 0.522592 -0.190206 -0.831095
vn -0.166750 -0.783099 -0.599125
vn 0.008137 0.692642 -0.721236
vn -0.833175 -0.121044 -0.539597
vn 0.015024 -0.219552 -0.975486
vn 0.843912 -0.118182 -0.523304
vn 0.011020 -0.830883 -0.556337
vn 0.194964 0.837212 -0.510945
vn -0.578512 0.012200 -0.815580
vn 0.368061 0.022325 -0.929529
vn 0.883673 0.016960 -0.467797
vn 0.232706 -0.788262 -0.569641
vn 0.131557 0.846092 -0.516547
vn -0.779768 -0.130504 -0.612313
vn 0.288854 -0.233094 -0.928563
vn 0.910799 -0.118142 -0.395588
vn 0.143403 -0.912710 -0.382617
vn -0.007381 -0.578764 0.815462
vn -0.002865 -0.580759 -0.814070
vn -0.069344 0.781998 -0.619412
vn -0.074928 0.781251 0.619703
vn -0.008406 -0.003192 0.999957
vn -0.002907 0.001918 -0.999991
vn -0.727877 -0.000562 -0.685704
vn -0.733049 0.680164 -0.004034
vn -0.731826 -0.002031 0.681487
vn -0.999972 -0.000955 -0.007055
vn -0.829882 -0.557923 -0.004042
vn 0.732149 -0.000548 -0.681141
vn 0.628082 0.778147 0.000665
vn 0.728459 -0.002006 0.685084
vn 0.999996 -0.000845 -0.001407
vn 0.833145 -0.553055 0.000572
vn 0.116807 0.145414 0.982451
vn 0.118115 0.148585 -0.981820
vn -0.061467 0.732698 -0.677773
vn -0.065447 0.733725 0.676287
vn -0.007617 -0.002849 0.999964
vn -0.002126 0.001978 -0.999992
vn -0.630414 -0.000949 -0.776257
vn -0.623621 0.781713 -0.004682
vn -0.635289 -0.002203 0.772269
vn -0.999968 -0.001801 -0.007382
vn -0.940999 0.338359 -0.005798
vn 0.636010 -0.000932 -0.771678
vn 0.569663 0.821877 -0.001547
vn 0.632274 -0.002165 0.774739
vn 0.999995 -0.001629 -0.001759
vn 0.982709 -0.185083 0.005328
vn 0.064404 0.127590 0.989735
vn 0.062986 0.178704 -0.981884
vn -0.001579 0.506051 -0.862502
vn -0.006793 0.592709 0.805388
vn -0.007944 -0.002971 0.999962
vn -0.000779 0.002162 -0.999994
vn -0.617125 0.011375 -0.786780
vn -0.765879 0.642958 -0.005809
vn -0.679293 0.009921 0.733798
vn -0.999516 0.030237 -0.007274
vn -0.952465 0.304567 -0.007005
vn 0.623262 0.012648 -0.781909
vn 0.767954 0.640504 -0.001514
vn 0.676308 0.011219 0.736532
vn 0.999444 0.033197 -0.001638
vn 0.996664 -0.081616 0.001640
vn 0.222707 0.689658 -0.689038
vn 0.641462 0.226244 -0.733034
vn 0.290058 0.271349 -0.917735
vn -0.128378 0.272010 -0.953693
vn 0.289750 -0.215477 -0.932531
vn -0.218859 0.689658 -0.690269
vn -0.637367 0.226244 -0.736599
vn -0.284933 0.271349 -0.919339
vn 0.133695 0.272010 -0.952962
vn -0.284543 -0.215477 -0.934133
vn -0.981830 0.010384 -0.189467
vn 0.013802 -0.980215 -0.197452
vn 0.067206 0.061273 -0.995854
vn 0.012269 0.981955 -0.188714
vn 0.984637 0.011964 -0.174192
vn 0.575643 0.577325 0.579079
vn -0.578782 0.577104 0.576162
vn -0.711149 0.700779 0.056351
vn 0.833577 0.552304 -0.010478
vn 0.668740 0.735259 -0.110368
vn -0.676051 0.598047 -0.430460
vn 0.558922 0.794121 -0.238700
vn -0.695922 0.718014 -0.012180
vn 0.000848 0.553517 -0.832838
vn 0.406609 -0.816389 0.410096
vn -0.667821 -0.333370 0.665492
vn -0.449401 -0.885100 -0.120985
vn 0.830260 -0.548119 -0.101162
vn 0.637736 -0.652562 -0.409213
vn -0.521667 -0.384633 -0.761526
vn 0.422537 -0.506169 -0.751835
vn -0.651230 -0.634843 -0.415780
vn 0.001697 -0.160513 -0.987032

#228 faces (verts: 168..310)
usemtl 0x001
s 1
f 169/721/169 168/722/168 170/723/170
usemtl 0x001
s 1
f 170/724/170 168/725/168 171/726/171
usemtl 0x001
s 1
f 171/727/171 168/728/168 172/729/172
usemtl 0x001
s 1
f 172/730/172 168/731/168 173/732/173
usemtl 0x001
s 1
f 173/733/173 168/734/168 174/735/174
usemtl 0x001
s 1
f 174/736/174 168/737/168 175/738/175
usemtl 0x001
s 1
f 175/739/175 168/740/168 176/741/176
usemtl 0x001
s 1
f 176/742/176 168/743/168 177/744/177
usemtl 0x001
s 1
f 177/745/177 168/746/168 178/747/178
usemtl 0x001
s 1
f 178/748/178 168/749/168 169/750/169
usemtl 0x001
s 1
f 179/751/179 169/752/169 180/753/180
usemtl 0x001
s 1
f 180/754/180 169/755/169 170/756/170
usemtl 0x001
s 1
f 180/757/180 170/758/170 181/759/181
usemtl 0x001
s 1
f 181/760/181 170/761/170 171/762/171
usemtl 0x001
s 1
f 181/763/181 171/764/171 182/765/182
usemtl 0x001
s 1
f 182/766/182 171/767/171 172/768/172
usemtl 0x001
s 1
f 182/769/182 172/770/172 183/771/183
usemtl 0x001
s 1
f 183/772/183 172/773/172 173/774/173
usemtl 0x001
s 1
f 183/775/183 173/776/173 184/777/184
usemtl 0x001
s 1
f 184/778/184 173/779/173 174/780/174
usemtl 0x001
s 1
f 184/781/184 174/782/174 185/783/185
usemtl 0x001
s 1
f 185/784/185 174/785/174 175/786/175
usemtl 0x001
s 1
f 185/787/185 175/788/175 186/789/186
usemtl 0x001
s 1
f 186/790/186 175/791/175 176/792/176
usemtl 0x001
s 1
f 186/793/186 176/794/176 187/795/187
usemtl 0x001
s 1
f 187/796/187 176/797/176 177/798/177
usemtl 0x001
s 1
f 187/799/187 177/800/177 188/801/188
usemtl 0x001
s 1
f 188/802/188 177/803/177 178/804/178
usemtl 0x001
s 1
f 188/805/188 178/806/178 179/807/179
usemtl 0x001
s 1
f 179/808/179 178/809/178 169/810/169
usemtl 0x001
s 1
f 189/811/189 179/812/179 190/813/190
usemtl 0x001
s 1
f 190/814/190 179/815/179 180/816/180
usemtl 0x001
s 1
f 190/817/190 180/818/180 191/819/191
usemtl 0x001
s 1
f 191/820/191 180/821/180 181/822/181
usemtl 0x001
s 1
f 191/823/191 181/824/181 192/825/192
usemtl 0x001
s 1
f 192/826/192 181/827/181 182/828/182
usemtl 0x001
s 1
f 192/829/192 182/830/182 193/831/193
usemtl 0x001
s 1
f 193/832/193 182/833/182 183/834/183
usemtl 0x001
s 1
f 193/835/193 183/836/183 194/837/194
usemtl 0x001
s 1
f 194/838/194 183/839/183 184/840/184
usemtl 0x001
s 1
f 194/841/194 184/842/184 195/843/195
usemtl 0x001
s 1
f 195/844/195 184/845/184 185/846/185
usemtl 0x001
s 1
f 195/847/195 185/848/185 196/849/196
usemtl 0x001
s 1
f 196/850/196 185/851/185 186/852/186
usemtl 0x001
s 1
f 196/853/196 186/854/186 197/855/197
usemtl 0x001
s 1
f 197/856/197 186/857/186 187/858/187
usemtl 0x001
s 1
f 197/859/197 187/860/187 198/861/198
usemtl 0x001
s 1
f 198/862/198 187/863/187 188/864/188
usemtl 0x001
s 1
f 198/865/198 188/866/188 189/867/189
usemtl 0x001
s 1
f 189/868/189 188/869/188 179/870/179
usemtl 0x001
s 1
f 199/871/199 189/872/189 200/873/200
usemtl 0x001
s 1
f 200/874/200 189/875/189 190/876/190
usemtl 0x001
s 1
f 200/877/200 190/878/190 201/879/201
usemtl 0x001
s 1
f 201/880/201 190/881/190 191/882/191
usemtl 0x001
s 1
f 201/883/201 191/884/191 202/885/202
usemtl 0x001
s 1
f 202/886/202 191/887/191 192/888/192
usemtl 0x001
s 1
f 202/889/202 192/890/192 203/891/203
usemtl 0x001
s 1
f 203/892/203 192/893/192 193/894/193
usemtl 0x001
s 1
f 203/895/203 193/896/193 204/897/204
usemtl 0x001
s 1
f 204/898/204 193/899/193 194/900/194
usemtl 0x001
s 1
f 204/901/204 194/902/194 205/903/205
usemtl 0x001
s 1
f 205/904/205 194/905/194 195/906/195
usemtl 0x001
s 1
f 205/907/205 195/908/195 206/909/206
usemtl 0x001
s 1
f 206/910/206 195/911/195 196/912/196
usemtl 0x001
s 1
f 206/913/206 196/914/196 207/915/207
usemtl 0x001
s 1
f 207/916/207 196/917/196 197/918/197
usemtl 0x001
s 1
f 207/919/207 197/920/197 208/921/208
usemtl 0x001
s 1
f 208/922/208 197/923/197 198/924/198
usemtl 0x001
s 1
f 208/925/208 198/926/198 199/927/199
usemtl 0x001
s 1
f 199/928/199 198/929/198 189/930/189
usemtl 0x001
s 1
f 207/931/207 209/932/209 206/933/206
usemtl 0x001
s 1
f 208/934/208 209/935/209 207/936/207
usemtl 0x001
s 1
f 199/937/199 209/938/209 208/939/208
usemtl 0x001
s 1
f 200/940/200 209/941/209 199/942/199
usemtl 0x001
s 1
f 201/943/201 209/944/209 200/945/200
usemtl 0x001
s 1
f 202/946/202 209/947/209 201/948/201
usemtl 0x001
s 1
f 203/949/203 209/950/209 202/951/202
usemtl 0x001
s 1
f 204/952/204 209/953/209 203/954/203
usemtl 0x001
s 1
f 205/955/205 209/956/209 204/957/204
usemtl 0x001
s 1
f 206/958/206 209/959/209 205/960/205
usemtl 0x001
s 1
f 212/961/212 211/962/211 210/963/210
usemtl 0x001
s 1
f 213/964/213 212/965/212 210/966/210
usemtl 0x001
s 1
f 211/967/211 212/968/212 214/969/214
usemtl 0x001
s 1
f 212/970/212 213/971/213 214/972/214
usemtl 0x001
s 1
f 217/973/217 216/974/216 215/975/215
usemtl 0x001
s 1
f 218/976/218 217/977/217 215/978/215
usemtl 0x001
s 1
f 216/979/216 217/980/217 219/981/219
usemtl 0x001
s 1
f 217/982/217 218/983/218 219/984/219
usemtl 0x001
s 1
f 222/985/222 221/986/221 220/987/220
usemtl 0x001
s 1
f 223/988/223 222/989/222 220/990/220
usemtl 0x001
s 1
f 221/991/221 222/992/222 224/993/224
usemtl 0x001
s 1
f 222/994/222 223/995/223 224/996/224
usemtl 0x001
s 1
f 227/997/227 226/998/226 225/999/225
usemtl 0x001
s 1
f 228/1000/228 227/1001/227 225/1002/225
usemtl 0x001
s 1
f 226/1003/226 227/1004/227 229/1005/229
usemtl 0x001
s 1
f 227/1006/227 228/1007/228 229/1008/229
usemtl 0x001
s 1
f 235/1009/235 236/1010/236 232/1011/232
usemtl 0x001
s 1
f 232/1012/232 236/1013/236 237/1014/237
usemtl 0x001
s 1
f 237/1015/237 238/1016/238 233/1017/233
usemtl 0x001
s 1
f 236/1018/236 240/1019/240 239/1020/239
usemtl 0x001
s 1
f 236/1021/236 239/1022/239 237/1023/237
usemtl 0x001
s 1
f 237/1024/237 239/1025/239 238/1026/238
usemtl 0x001
s 1
f 240/1027/240 230/1028/230 238/1029/238
usemtl 0x001
s 1
f 231/1030/231 240/1031/240 236/1032/236
usemtl 0x001
s 1
f 239/1033/239 240/1034/240 238/1035/238
usemtl 0x001
s 1
f 233/1036/233 238/1037/238 234/1038/234
usemtl 0x001
s 1
f 236/1039/236 235/1040/235 231/1041/231
usemtl 0x001
s 1
f 230/1042/230 234/1043/234 238/1044/238
usemtl 0x001
s 1
f 232/1045/232 241/1046/241 235/1047/235
usemtl 0x001
s 1
f 242/1048/242 241/1049/241 232/1050/232
usemtl 0x001
s 1
f 233/1051/233 243/1052/243 242/1053/242
usemtl 0x001
s 1
f 244/1054/244 245/1055/245 241/1056/241
usemtl 0x001
s 1
f 242/1057/242 244/1058/244 241/1059/241
usemtl 0x001
s 1
f 243/1060/243 244/1061/244 242/1062/242
usemtl 0x001
s 1
f 243/1063/243 230/1064/230 245/1065/245
usemtl 0x001
s 1
f 241/1066/241 245/1067/245 231/1068/231
usemtl 0x001
s 1
f 243/1069/243 245/1070/245 244/1071/244
usemtl 0x001
s 1
f 234/1072/234 243/1073/243 233/1074/233
usemtl 0x001
s 1
f 231/1075/231 235/1076/235 241/1077/241
usemtl 0x001
s 1
f 243/1078/243 234/1079/234 230/1080/230
usemtl 0x001
s 1
f 251/1081/251 252/1082/252 248/1083/248
usemtl 0x001
s 1
f 248/1084/248 252/1085/252 253/1086/253
usemtl 0x001
s 1
f 253/1087/253 254/1088/254 249/1089/249
usemtl 0x001
s 1
f 252/1090/252 256/1091/256 255/1092/255
usemtl 0x001
s 1
f 252/1093/252 255/1094/255 253/1095/253
usemtl 0x001
s 1
f 253/1096/253 255/1097/255 254/1098/254
usemtl 0x001
s 1
f 256/1099/256 246/1100/246 254/1101/254
usemtl 0x001
s 1
f 247/1102/247 256/1103/256 252/1104/252
usemtl 0x001
s 1
f 255/1105/255 256/1106/256 254/1107/254
usemtl 0x001
s 1
f 249/1108/249 254/1109/254 250/1110/250
usemtl 0x001
s 1
f 252/1111/252 251/1112/251 247/1113/247
usemtl 0x001
s 1
f 246/1114/246 250/1115/250 254/1116/254
usemtl 0x001
s 1
f 248/1117/248 257/1118/257 251/1119/251
usemtl 0x001
s 1
f 258/1120/258 257/1121/257 248/1122/248
usemtl 0x001
s 1
f 249/1123/249 259/1124/259 258/1125/258
usemtl 0x001
s 1
f 260/1126/260 261/1127/261 257/1128/257
usemtl 0x001
s 1
f 258/1129/258 260/1130/260 257/1131/257
usemtl 0x001
s 1
f 259/1132/259 260/1133/260 258/1134/258
usemtl 0x001
s 1
f 259/1135/259 246/1136/246 261/1137/261
usemtl 0x001
s 1
f 257/1138/257 261/1139/261 247/1140/247
usemtl 0x001
s 1
f 259/1141/259 261/1142/261 260/1143/260
usemtl 0x001
s 1
f 250/1144/250 259/1145/259 249/1146/249
usemtl 0x001
s 1
f 247/1147/247 251/1148/251 257/1149/257
usemtl 0x001
s 1
f 259/1150/259 250/1151/250 246/1152/246
usemtl 0x001
s 1
f 267/1153/267 268/1154/268 264/1155/264
usemtl 0x001
s 1
f 264/1156/264 268/1157/268 269/1158/269
usemtl 0x001
s 1
f 269/1159/269 270/1160/270 265/1161/265
usemtl 0x001
s 1
f 268/1162/268 272/1163/272 271/1164/271
usemtl 0x001
s 1
f 268/1165/268 271/1166/271 269/1167/269
usemtl 0x001
s 1
f 269/1168/269 271/1169/271 270/1170/270
usemtl 0x001
s 1
f 272/1171/272 262/1172/262 270/1173/270
usemtl 0x001
s 1
f 263/1174/263 272/1175/272 268/1176/268
usemtl 0x001
s 1
f 271/1177/271 272/1178/272 270/1179/270
usemtl 0x001
s 1
f 265/1180/265 270/1181/270 266/1182/266
usemtl 0x001
s 1
f 268/1183/268 267/1184/267 263/1185/263
usemtl 0x001
s 1
f 262/1186/262 266/1187/266 270/1188/270
usemtl 0x001
s 1
f 264/1189/264 273/1190/273 267/1191/267
usemtl 0x001
s 1
f 274/1192/274 273/1193/273 264/1194/264
usemtl 0x001
s 1
f 265/1195/265 275/1196/275 274/1197/274
usemtl 0x001
s 1
f 276/1198/276 277/1199/277 273/1200/273
usemtl 0x001
s 1
f 274/1201/274 276/1202/276 273/1203/273
usemtl 0x001
s 1
f 275/1204/275 276/1205/276 274/1206/274
usemtl 0x001
s 1
f 275/1207/275 262/1208/262 277/1209/277
usemtl 0x001
s 1
f 273/1210/273 277/1211/277 263/1212/263
usemtl 0x001
s 1
f 275/1213/275 277/1214/277 276/1215/276
usemtl 0x001
s 1
f 266/1216/266 275/1217/275 265/1218/265
usemtl 0x001
s 1
f 263/1219/263 267/1220/267 273/1221/273
usemtl 0x001
s 1
f 275/1222/275 266/1223/266 262/1224/262
usemtl 0x001
s 1
f 247/1225/247 242/1226/242 232/1227/232
usemtl 0x001
s 1
f 247/1228/247 261/1229/261 242/1230/242
usemtl 0x001
s 1
f 261/1231/261 246/1232/246 242/1233/242
usemtl 0x001
s 1
f 242/1234/242 246/1235/246 233/1236/233
usemtl 0x001
s 1
f 263/1237/263 258/1238/258 248/1239/248
usemtl 0x001
s 1
f 263/1240/263 277/1241/277 258/1242/258
usemtl 0x001
s 1
f 277/1243/277 262/1244/262 258/1245/258
usemtl 0x001
s 1
f 249/1246/249 258/1247/258 262/1248/262
usemtl 0x001
s 1
f 248/1249/248 272/1250/272 263/1251/263
usemtl 0x001
s 1
f 248/1252/248 253/1253/253 272/1254/272
usemtl 0x001
s 1
f 253/1255/253 249/1256/249 272/1257/272
usemtl 0x001
s 1
f 249/1258/249 262/1259/262 272/1260/272
usemtl 0x001
s 1
f 247/1261/247 232/1262/232 256/1263/256
usemtl 0x001
s 1
f 256/1264/256 232/1265/232 237/1266/237
usemtl 0x001
s 1
f 237/1267/237 233/1268/233 256/1269/256
usemtl 0x001
s 1
f 233/1270/233 246/1271/246 256/1272/256
usemtl 0x001
s 1
f 278/1273/278 279/1274/279 280/1275/280
usemtl 0x001
s 1
f 278/1276/278 280/1277/280 281/1278/281
usemtl 0x001
s 1
f 282/1279/282 280/1280/280 279/1281/279
usemtl 0x001
s 1
f 282/1282/282 281/1283/281 280/1284/280
usemtl 0x001
s 1
f 285/1285/285 284/1286/284 283/1287/283
usemtl 0x001
s 1
f 286/1288/286 285/1289/285 283/1290/283
usemtl 0x001
s 1
f 284/1291/284 285/1292/285 287/1293/287
usemtl 0x001
s 1
f 285/1294/285 286/1295/286 287/1296/287
usemtl 0x001
s 1
f 288/1297/288 290/1298/290 289/1299/289
usemtl 0x001
s 1
f 288/1300/288 291/1301/291 290/1302/290
usemtl 0x001
s 1
f 292/1303/292 290/1304/290 291/1305/291
usemtl 0x001
s 1
f 292/1306/292 289/1307/289 290/1308/290
usemtl 0x000
s 1
f 293/1309/293 295/1310/295 294/1311/294
usemtl 0x000
s 1
f 293/1312/293 296/1313/296 295/1314/295
usemtl 0x000
s 1
f 297/1315/297 295/1316/295 296/1317/296
usemtl 0x000
s 1
f 298/1318/298 300/1319/300 299/1320/299
usemtl 0x000
s 1
f 300/1321/300 297/1322/297 299/1323/299
usemtl 0x000
s 1
f 298/1324/298 299/1325/299 301/1326/301
usemtl 0x000
s 1
f 300/1327/300 295/1328/295 297/1329/297
usemtl 0x000
s 1
f 303/1330/303 304/1331/304 302/1332/302
usemtl 0x000
s 1
f 304/1333/304 305/1334/305 302/1335/302
usemtl 0x000
s 1
f 305/1336/305 304/1337/304 306/1338/306
usemtl 0x000
s 1
f 308/1339/308 309/1340/309 307/1341/307
usemtl 0x000
s 1
f 308/1342/308 306/1343/306 309/1344/309
usemtl 0x000
s 1
f 310/1345/310 308/1346/308 307/1347/307
usemtl 0x000
s 1
f 306/1348/306 304/1349/304 309/1350/309
usemtl 0x000
s 1
f 302/1351/302 305/1352/305 293/1353/293
usemtl 0x000
s 1
f 305/1354/305 296/1355/296 293/1356/293
usemtl 0x000
s 1
f 305/1357/305 306/1358/306 296/1359/296
usemtl 0x000
s 1
f 306/1360/306 297/1361/297 296/1362/296
usemtl 0x000
s 1
f 306/1363/306 308/1364/308 297/1365/297
usemtl 0x000
s 1
f 308/1366/308 299/1367/299 297/1368/297
usemtl 0x000
s 1
f 308/1369/308 310/1370/310 299/1371/299
usemtl 0x000
s 1
f 310/1372/310 301/1373/301 299/1374/299
usemtl 0x000
s 1
f 303/1375/303 295/1376/295 304/1377/304
usemtl 0x000
s 1
f 294/1378/294 295/1379/295 303/1380/303
usemtl 0x000
s 1
f 304/1381/304 295/1382/295 309/1383/309
usemtl 0x000
s 1
f 300/1384/300 309/1385/309 295/1386/295
usemtl 0x000
s 1
f 309/1387/309 300/1388/300 307/1389/307
usemtl 0x000
s 1
f 298/1390/298 307/1391/307 300/1392/300
usemtl 0x000
s 1
f 310/1393/310 307/1394/307 298/1395/298
usemtl 0x000
s 1
f 298/1396/298 301/1397/301 310/1398/310
usemtl 0x000
s 1
f 293/1399/293 303/1400/303 302/1401/302
usemtl 0x000
s 1
f 293/1402/293 294/1403/294 303/1404/303


o :HRFW
#part position 0.004065 -0.579950 0.786859

#4 verts
v 0.004825 -0.411364 -1.022349
v 0.003304 -0.411364 -0.551370
v 0.004825 -0.748537 -1.022349
v 0.003304 -0.748537 -0.551370

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645

#2 faces (verts: 311..314)
usemtl 0x000
s 1
f 311/1405/311 313/1406/313 312/1407/312
usemtl 0x000
s 1
f 313/1408/313 314/1409/314 312/1410/312


o DAMAGE_:HRFW
#part position 0.004065 -0.579950 0.786859

#4 verts
v 0.004825 -0.411364 -1.022349
v 0.003304 -0.411364 -0.551370
v 0.004825 -0.748537 -1.022349
v 0.003304 -0.748537 -0.551370

#6 vt
vt 0.406288 0.996765
vt 0.406288 0.778614
vt 0.989478 0.996765
vt 0.406288 0.778614
vt 0.989478 0.778614
vt 0.989478 0.996765

#4 normals
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645
vn -0.995928 -0.579950 -0.789644
vn -0.995929 -0.579950 -0.789645

#2 faces (verts: 315..318)
usemtl 0x000
s 1
f 315/1411/315 317/1412/317 316/1413/316
usemtl 0x000
s 1
f 317/1414/317 318/1415/318 316/1416/316


o POSITION_:HLRW
#part position -0.001832 -0.579950 -1.036170

v 0.098168 -0.579950 1.036170
v -0.101832 -0.579950 1.036170
v -0.001832 -0.479950 1.036170
v -0.001832 -0.679950 1.036170
v -0.001832 -0.579950 1.136170
v -0.001832 -0.579950 0.936170

#f 473..480 (8)
f 321 324 319
f 321 320 324
f 321 323 320
f 321 319 323
f 322 319 324
f 322 324 320
f 322 320 323
f 322 323 319

o POSITION_:HRRW
#part position -0.001832 -0.579950 -1.036170

v 0.098168 -0.579950 1.036170
v -0.101832 -0.579950 1.036170
v -0.001832 -0.479950 1.036170
v -0.001832 -0.679950 1.036170
v -0.001832 -0.579950 1.136170
v -0.001832 -0.579950 0.936170

#f 481..488 (8)
f 327 330 325
f 327 326 330
f 327 329 326
f 327 325 329
f 328 325 330
f 328 330 326
f 328 326 329
f 328 329 325

o POSITION_:HLFW
#part position 0.004065 -0.579950 0.786859

v 0.104065 -0.579950 -0.786859
v -0.095935 -0.579950 -0.786859
v 0.004065 -0.479950 -0.786859
v 0.004065 -0.679950 -0.786859
v 0.004065 -0.579950 -0.686859
v 0.004065 -0.579950 -0.886859

#f 489..496 (8)
f 333 336 331
f 333 332 336
f 333 335 332
f 333 331 335
f 334 331 336
f 334 336 332
f 334 332 335
f 334 335 331

o POSITION_:HB
#part position 0.000000 0.000000 -0.000000

v 0.100000 0.000000 0.000000
v -0.100000 0.000000 0.000000
v 0.000000 0.100000 0.000000
v 0.000000 -0.100000 0.000000
v 0.000000 0.000000 0.100000
v 0.000000 0.000000 -0.100000

#f 497..504 (8)
f 339 342 337
f 339 338 342
f 339 341 338
f 339 337 341
f 340 337 342
f 340 342 338
f 340 338 341
f 340 341 337

o POSITION_:HRFW
#part position 0.004065 -0.579950 0.786859

v 0.104065 -0.579950 -0.786859
v -0.095935 -0.579950 -0.786859
v 0.004065 -0.479950 -0.786859
v 0.004065 -0.679950 -0.786859
v 0.004065 -0.579950 -0.686859
v 0.004065 -0.579950 -0.886859

#f 505..512 (8)
f 345 348 343
f 345 344 348
f 345 347 344
f 345 343 347
f 346 343 348
f 346 348 344
f 346 344 347
f 346 347 343
"""
    assert pathlib.Path("./scripts/bfut_Fce2Obj.py").exists()
    assert filepath_fce_input.exists()
    p = subprocess.run(f"python ./scripts/bfut_Fce2Obj.py {str(filepath_fce_input)}",
                       shell=True, capture_output=True, encoding="utf8", check=True)
    outpath = (filepath_fce_input.parent / filepath_fce_input.stem).with_suffix(".obj")
    assert outpath.exists()
    obj_output = outpath.read_text(encoding="utf-8")
    outpath.unlink()
    outpath.with_suffix(".mtl").unlink()
    assert p.returncode == 0 and len(p.stderr) == 0 and obj_output == fcecodec_Fce2Obj_src


def test_MergeAllParts():
    assert pathlib.Path("./scripts/bfut_MergeAllParts.py").exists()
    assert filepath_fce_input.exists()
    p = subprocess.run(
        f"python ./scripts/bfut_MergeAllParts.py {str(filepath_fce_input)}",
        shell=True, capture_output=True, encoding="utf8", check=True)
    outpath = filepath_fce_input.parent / (filepath_fce_input.stem + "_out" + filepath_fce_input.suffix)
    assert pathlib.Path("./tests/fce/test_scripts_MergeAllParts_4_Snowman_car.fce").exists()
    assert outpath.exists()
    p_cmp = subprocess.run(f"cmp ./tests/fce/test_scripts_MergeAllParts_4_Snowman_car.fce {str(outpath)}", shell=True, check=True)
    p_cksum = subprocess.run(f"cksum ./tests/fce/test_scripts_MergeAllParts_4_Snowman_car.fce {str(outpath)}", shell=True, check=True)
    print(p_cksum.stdout)
    print(p_cksum.stderr)
    if p_cksum.returncode != 0:
        print(p_cksum.stderr)
    outpath.unlink()
    assert p.returncode == 0
    assert len(p.stderr) == 0
    assert p_cmp.returncode == 0


def test_PrintFceInfo():
    fcecodec_PrintFceInfo_src = \
"""Filesize = 46556 (0xb5dc)
Version = FCE4
NumTriangles = 236 (* 12 = 2832) (* 56 = 13216)
NumVertices = 159 (* 4 = 636)  (* 12 = 1908)  (* 32 = 5088)
NumArts = 1
XHalfSize = 0.484685
YHalfSize = 0.751403
ZHalfSize = 1.305500
NumParts = 5
NumDummies = 0
NumColors = 8
VertTblOffset = 0x0000 (0x2038), Size = 1908
NormTblOffset = 0x0774 (0x27ac), Size = 1908
TriaTblOffset = 0x0ee8 (0x2f20), Size = 13216
Reserve1offset = 0x4288 (0x62c0), Size = 5088
Reserve2offset = 0x5668 (0x76a0), Size = 1908
Reserve3offset = 0x5ddc (0x7e14), Size = 1908
UndamgdVertTblOffset = 0x6550 (0x8588), Size = 1908
UndamgdNormTblOffset = 0x6cc4 (0x8cfc), Size = 1908
DamgdVertTblOffset = 0x7438 (0x9470), Size = 1908
DamgdNormTblOffset = 0x7bac (0x9be4), Size = 1908
Reserve4offset = 0x8320 (0xa358), Size = 636
AnimationTblOffset = 0x859c (0xa5d4), Size = 636
Reserve5offset = 0x8818 (0xa850), Size = 636
Reserve6offset = 0x8a94 (0xaacc), Size = 2832
Unknown1 (0x0004) = 0 (0x0000)
Unknown3 (0x0924) = 0 (0x0000)
Parts:
Idx  Verts       Triangles   (PartPos)                         Name
  0      0     4     0     2 (-0.001832, -0.579950, -1.036170) :HLRW
  1      4     4     2     2 (-0.001832, -0.579950, -1.036170) :HRRW
  2      8     4     4     2 ( 0.004065, -0.579950,  0.786859) :HLFW
  3     12   143     6   228 ( 0.000000,  0.000000, -0.000000) :HB
  4    155     4   234     2 ( 0.004065, -0.579950,  0.786859) :HRFW
         =   159     =   236
FCE4 Filesize (verts, triags) = 46556 (0xb5dc), diff=0
FCE4M Filesize (verts, triags) = 46715 (0xb67b), diff=-159
DummyNames (Position):
Car colors (hue, saturation, brightness, transparency):
 0  Primary     170, 154,  91, 128
 0  Interior    255, 152, 159, 128
 0  Secondary    25, 123, 114, 127
 0  Driver hair 255, 152, 159, 127
 1  Primary      33, 115, 181, 127
 1  Interior    170,  65, 128, 128
 1  Secondary   255,   9,  26, 127
 1  Driver hair 170,  65, 128, 127
 2  Primary      18, 254, 255,   0
 2  Interior    212,   2,  96, 128
 2  Secondary   255,   9,  26, 127
 2  Driver hair 212,   2,  96, 127
 3  Primary      91, 213,  49, 127
 3  Interior    170,  21, 175, 128
 3  Secondary   255,   9,  26, 127
 3  Driver hair 170,  21, 175, 127
 4  Primary     255, 254, 165, 127
 4  Interior    170,  65, 128, 128
 4  Secondary    25, 123, 114, 127
 4  Driver hair 170,  65, 128, 127
 5  Primary     170, 184, 255,   0
 5  Interior     27, 127, 192, 128
 5  Secondary   255,   9,  26, 127
 5  Driver hair  27, 127, 192, 127
 6  Primary     255, 254,   0,   0
 6  Interior    170,  21, 175, 128
 6  Secondary    24, 123, 114, 127
 6  Driver hair 170,  21, 175, 127
 7  Primary     255,   1, 255,   0
 7  Interior    255, 152, 159, 128
 7  Secondary   255,   9,  26, 127
 7  Driver hair 170,  65, 128, 127
"""
    assert pathlib.Path("./scripts/bfut_PrintFceInfo.py").exists()
    assert filepath_fce_input.exists()
    p = subprocess.run(f"python ./scripts/bfut_PrintFceInfo.py {str(filepath_fce_input)}",
                       shell=True, capture_output=True, encoding="utf8", check=True)
    assert p.returncode == 0 and len(p.stderr) == 0 and p.stdout == fcecodec_PrintFceInfo_src
